
/* Chrysalide - Outil d'analyse de fichiers binaires
 * dwarf.c - support du format DWARF v2
 *
 * Copyright (C) 2015-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "dwarf.h"


#include "../dwarf-int.h"


#include "form.h"



/* Format de débogage DWARF v2 (instance) */
struct _GDwarfV2Format
{
    GDwarfFormat parent;                    /* A laisser en premier        */

};

/* Format de débogage DWARF v2 (classe) */
struct _GDwarfV2FormatClass
{
    GDwarfFormatClass parent;               /* A laisser en premier        */

};


/* Initialise la classe des formats de débogage DWARF v2. */
static void g_dwarfv2_format_class_init(GDwarfV2FormatClass *);

/* Initialise une instance de format de débogage DWARF v2. */
static void g_dwarfv2_format_init(GDwarfV2Format *);

/* Supprime toutes les références externes. */
static void g_dwarfv2_format_dispose(GDwarfV2Format *);

/* Procède à la libération totale de la mémoire. */
static void g_dwarfv2_format_finalize(GDwarfV2Format *);



/* Indique le type défini pour un format de débogage DWARF v2. */
G_DEFINE_TYPE(GDwarfV2Format, g_dwarfv2_format, G_TYPE_DWARF_FORMAT);


/******************************************************************************
*                                                                             *
*  Paramètres  : klass = classe à initialiser.                                *
*                                                                             *
*  Description : Initialise la classe des formats de débogage DWARF v2.       *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_dwarfv2_format_class_init(GDwarfV2FormatClass *klass)
{
    GObjectClass *object;                   /* Autre version de la classe  */
    GDwarfFormatClass *dwarf;               /* Version parente de la classe*/

    object = G_OBJECT_CLASS(klass);

    object->dispose = (GObjectFinalizeFunc/* ! */)g_dwarfv2_format_dispose;
    object->finalize = (GObjectFinalizeFunc)g_dwarfv2_format_finalize;

    dwarf = G_DWARF_FORMAT_CLASS(klass);

    dwarf->read_form = (read_form_value_fc)read_dwarf_v2_form_value;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : format = instance à initialiser.                             *
*                                                                             *
*  Description : Initialise une instance de format de débogage DWARF v2.      *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_dwarfv2_format_init(GDwarfV2Format *format)
{

}


/******************************************************************************
*                                                                             *
*  Paramètres  : format = instance d'objet GLib à traiter.                    *
*                                                                             *
*  Description : Supprime toutes les références externes.                     *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_dwarfv2_format_dispose(GDwarfV2Format *format)
{
    G_OBJECT_CLASS(g_dwarfv2_format_parent_class)->dispose(G_OBJECT(format));

}


/******************************************************************************
*                                                                             *
*  Paramètres  : format = instance d'objet GLib à traiter.                    *
*                                                                             *
*  Description : Procède à la libération totale de la mémoire.                *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_dwarfv2_format_finalize(GDwarfV2Format *format)
{
    G_OBJECT_CLASS(g_dwarfv2_format_parent_class)->finalize(G_OBJECT(format));

}


/******************************************************************************
*                                                                             *
*  Paramètres  : content = contenu binaire à parcourir.                       *
*                parent  = éventuel format exécutable déjà chargé.            *
                 status  = barre de statut à tenir informée.                  *
*                                                                             *
*  Description : Prend en charge un nouveau format DWARF (v2).                *
*                                                                             *
*  Retour      : Adresse de la structure mise en place ou NULL en cas d'échec.*
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

GBinFormat *g_dwarfv2_format_new(GBinContent *content, GExeFormat *parent, GtkStatusStack *status)
{
    GDwarfV2Format *result;                 /* Structure à retourner       */

    result = g_object_new(G_TYPE_DWARFV2_FORMAT, NULL);



    g_binary_format_set_content(G_BIN_FORMAT(result), content);



    return G_BIN_FORMAT(result);

}
